@@ -141,7 +141,7 @@ def db_session(session_maker: sessionmaker,
         session.close()
 
 
-def validate_body(http_request: func.HttpRequest, json_schema: dict) -> Union[dict, ValidationError]:
+def validate_body(http_request: func.HttpRequest, json_schema: dict) -> dict:
     """
     Validates json data in http request against a json schema. Raises ValidationError if incorrect schema
     Require:
